# Relation Mapping from SAP LeanIX to Collibra
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra#introduction)
  * [Configuring Mapping of Relations](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra#configuring-mapping-of-relations)
  * [Simple Relation Strategy](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra#simple-relation-strategy)
  * [Complex Relation Strategy](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra#complex-relation-strategy)
  * [Intermediate Asset Strategy](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra#intermediate-asset-strategy)


Configure the mapping of relations between fact sheets to the relation between assets to enhance data governance and lineage tracking.
